@@ -23,6 +23,9 @@ def fast_local_function(data,mesh,terminal,edge,gamma,nu,Qterm,Pperm,Pterm):
     downstream_length   = np.sqrt(np.sum(np.square(mesh-downstream),axis=1))
     terminal_length     = np.sqrt(np.sum(np.square(mesh-terminal),axis=1))
     # Begin calculating reduced resistance and bifurcation ratios
+    print(upstream_length)
+    print(downstream_length)
+    print(terminal_length)
     R_terminal          = (8*nu/np.pi)*terminal_length
     R_terminal_sister   = (8*nu/np.pi)*downstream_length + (data[edge,25]-(8*nu/np.pi)*data[edge,20])
     f_terminal          = (1+((data[edge,22]*R_terminal_sister)/(Qterm*R_terminal))**(gamma/4)) ** (-1/gamma)
